@@ -321,15 +321,14 @@ class FixedVocabularyFieldMarshaller(SimpleFieldMarshaller):
             part of a multiadapter lookup of the appropriate
             marshaller.
         """
-        super(FixedVocabularyFieldMarshaller, self).__init__(
-            field, request)
+        super(FixedVocabularyFieldMarshaller, self).__init__(field, request)
 
     def unmarshall_to_closeup(self, entry, value):
         """Describe all values, not just the selected value."""
         unmarshalled = []
         for item in self.field.vocabulary:
             item_dict = {'token': item.token, 'title': item.title}
-            if value.title == item.title:
+            if value and value.title == item.title:
                 item_dict['selected'] = True
             unmarshalled.append(item_dict)
         return unmarshalled
